@@ -1,13 +1,11 @@
 from Products.Clouseau.config import *
 from Products.CMFCore.DirectoryView import registerDirectory
 
-registerDirectory('skins/Clouseau', product_globals)
+from zope.i18nmessageid import MessageFactory
+ClouseauMessageFactory = MessageFactory('clouseau')
+PloneMessageFactory = MessageFactory('plone')
 
-try:
-    import transaction
-except ImportError:
-    print "You must have Zope 2.9 for this library to work."
-    raise
+registerDirectory('skins/Clouseau', product_globals)
 
 from Products.CMFCore import utils
 from Products.Clouseau.tools.clouseautool import ClouseauTool
