@@ -6,8 +6,14 @@ from cStringIO import StringIO
 from Products.CMFCore.utils import getToolByName
 
 app = transaction_manager.beginAndGetApp()
-# login the current user
-portal = getToolByName(self, "portal_url").getPortalObject()
+
+# something has changed causing self not to be present
+try:
+    portal = getToolByName(self, "portal_url").getPortalObject()
+except NameError:
+    portal = app.unrestrictedTraverse("/".join(portal_path))
+    
+# login the current user    
 acl_users = portal.acl_users
 
 uid = acl_users.getUserById(userid)
@@ -35,11 +41,20 @@ else:
 # clean out variables
 del uid
 del acl_users
-del self
+
+try:
+    del self
+except NameError:
+    pass
+try:
+   del portal_path
+except NameError:
+    pass
+
 del transaction_manager
 del userid
 del StringIO
 del makerequest
 del newSecurityManager
 del setSite
-del getToolByName
+del getToolByName
\ No newline at end of file
