@@ -4,6 +4,10 @@ function showClouseau(context) {
 		// preserve compatibility with Plone 3
 		content_node = document.getElementById("region-content")
 	}
+	if (content_node == null) {
+		// in case the skin is missing those 2 ids, we default to 'content'
+		content_node = document.getElementById("content")
+	}
     var footer = content_node.nextSibling;
     var wrapper = content_node.parentNode;
     
